.:GetBlogName:.

.:IfInfiniteScrollEnabled:: .:IfInThread::
:: :. :. .:IfInThread:: .:IfRSSEnabled:::. .:IfAtomEnabled:::. :. .:GetStyleSheets:. .:GetBlogMetadataIfExists::override_theme_css_with:::. .:GetJSON-LD:.
.:IfInThreadAndHasFeeds:: .:IfFeedsEnabled::
.:IfRSSEnabled::RSS:. .:IfAtomEnabled::ATOM:.
:. :.

.:GetBlogDescription:.

.:GetBlogMetadataIfExists::github:::. .:GetBlogMetadataIfExists::gitlab:::. .:GetBlogMetadataIfExists::diaspora:::. .:GetBlogMetadataIfExists::mastodon:::.
.:IfCategories::
Categories
.:TreeForBlogCategories::

::
- {value}::
::

:.
:. .:IfChapters::
Chapters
.:GetChapters::

::
- {index}. {title}::
::

:.
:. .:IfPages::
:: :.